@@ -27,5 +27,5 @@ from toolchest_client.api.exceptions import ToolchestException, DataLimitError,
     ToolchestDownloadError
 from toolchest_client.api.query import Query
 from toolchest_client.api.status import Status, get_status
-from .tools.api import alphafold, bowtie2, cellranger_count, clustalo, kraken2, megahit, shi7, shogun_align,\
+from .tools.api import alphafold, bowtie2, cellranger_count, clustalo, demucs, kraken2, megahit, shi7, shogun_align,\
     shogun_filter, STAR, test, unicycler
